pub struct ConsolidateRequest {
pub memory_ids: Vec<String>,
pub topic_name: String,
pub agent_id: Option<String>,
pub summary: Option<String>,
pub supersede: Option<String>,
pub thread_id: Option<String>,
pub metadata: Option<String>,
}Fields
memory_ids: Vec<String>topic_name: Stringagent_id: Option<String>summary: Option<String>supersede: Option<String>thread_id: Option<String>metadata: Option<String>Implementations
Sourceimpl ConsolidateRequest
impl ConsolidateRequest
Sourcepub fn agent_id(&self) -> &str
pub fn agent_id(&self) -> &str
Returns the value of agent_id, or the default value if agent_id is unset.
Sourcepub fn summary(&self) -> &str
pub fn summary(&self) -> &str
Returns the value of summary, or the default value if summary is unset.
Sourcepub fn supersede(&self) -> &str
pub fn supersede(&self) -> &str
Returns the value of supersede, or the default value if supersede is unset.