pub struct RememberRequest {Show 15 fields
pub content: String,
pub memory_type: Option<String>,
pub scope: Option<String>,
pub importance: Option<f32>,
pub tags: Vec<String>,
pub metadata: Option<String>,
pub thread_id: Option<String>,
pub ttl_seconds: Option<u64>,
pub agent_id: Option<String>,
pub source_type: Option<String>,
pub source_id: Option<String>,
pub org_id: Option<String>,
pub decay_rate: Option<f32>,
pub created_by: Option<String>,
pub related_to: Vec<String>,
}Fields
content: Stringmemory_type: Option<String>scope: Option<String>importance: Option<f32>metadata: Option<String>JSON-encoded string
thread_id: Option<String>ttl_seconds: Option<u64>agent_id: Option<String>source_type: Option<String>source_id: Option<String>org_id: Option<String>decay_rate: Option<f32>created_by: Option<String>Implementations
Sourceimpl RememberRequest
impl RememberRequest
Sourcepub fn memory_type(&self) -> &str
pub fn memory_type(&self) -> &str
Returns the value of memory_type, or the default value if memory_type is unset.
Sourcepub fn scope(&self) -> &str
pub fn scope(&self) -> &str
Returns the value of scope, or the default value if scope is unset.
Sourcepub fn importance(&self) -> f32
pub fn importance(&self) -> f32
Returns the value of importance, or the default value if importance is unset.
Sourcepub fn metadata(&self) -> &str
pub fn metadata(&self) -> &str
Returns the value of metadata, or the default value if metadata is unset.
Sourcepub fn thread_id(&self) -> &str
pub fn thread_id(&self) -> &str
Returns the value of thread_id, or the default value if thread_id is unset.
Sourcepub fn ttl_seconds(&self) -> u64
pub fn ttl_seconds(&self) -> u64
Returns the value of ttl_seconds, or the default value if ttl_seconds is unset.
Sourcepub fn agent_id(&self) -> &str
pub fn agent_id(&self) -> &str
Returns the value of agent_id, or the default value if agent_id is unset.
Sourcepub fn source_type(&self) -> &str
pub fn source_type(&self) -> &str
Returns the value of source_type, or the default value if source_type is unset.
Sourcepub fn source_id(&self) -> &str
pub fn source_id(&self) -> &str
Returns the value of source_id, or the default value if source_id is unset.
Sourcepub fn org_id(&self) -> &str
pub fn org_id(&self) -> &str
Returns the value of org_id, or the default value if org_id is unset.
Sourcepub fn decay_rate(&self) -> f32
pub fn decay_rate(&self) -> f32
Returns the value of decay_rate, or the default value if decay_rate is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.