pub struct ScoredMemory {Show 13 fields
pub id: String,
pub content: String,
pub memory_type: String,
pub importance: f32,
pub score: f32,
pub created_at: String,
pub agent_id: String,
pub scope: String,
pub tags: Vec<String>,
pub metadata: String,
pub access_count: u64,
pub updated_at: String,
pub score_breakdown: Option<ScoreBreakdown>,
}Fields
id: Stringcontent: Stringmemory_type: Stringimportance: f32score: f32created_at: Stringagent_id: Stringscope: Stringmetadata: StringJSON-encoded string
access_count: u64updated_at: Stringscore_breakdown: Option<ScoreBreakdown>Trait Implementations
Sourceimpl Clone for ScoredMemory
impl Clone for ScoredMemory
Sourcefn clone(&self) -> ScoredMemory
fn clone(&self) -> ScoredMemory
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScoredMemory
impl Debug for ScoredMemory
Sourceimpl Default for ScoredMemory
impl Default for ScoredMemory
Sourceimpl Message for ScoredMemory
impl Message for ScoredMemory
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ScoredMemory
impl PartialEq for ScoredMemory
impl StructuralPartialEq for ScoredMemory